<?php

/**
 * @file
 * Contains \Drupal\hyvortalk\Form\HyvorTalkConfigForm.
 */

namespace Drupal\hyvortalk\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class HyvorTalkConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'hyvortalk_config_form';
  }
 
  /**
   * {@inheritdoc}
   */ 
  public function buildForm(array $form, FormStateInterface $form_state) {
 
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('hyvortalk.settings');
    $form['hyvor_talk_website_id'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Hyvor Talk website ID'),
      '#default_value' => $config->get('hyvortalk.hyvor_talk_website_id'),
      '#required' => TRUE,
    );

    $form['hyvor_talk_load_mode'] = array(
      '#type' => 'select',
      '#options' => ['default' => 'Default', 'scroll' => 'Scroll', 'click' => 'Click'],
      '#title' => $this->t('Comment loading mode'),
      '#default_value' => $config->get('hyvortalk.hyvor_talk_load_mode'),
      '#required' => TRUE,
    );
 
    return $form;
  }
 
  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
 
    $config = $this->config('hyvortalk.settings');
    $config->set('hyvortalk.hyvor_talk_website_id', $form_state->getValue('hyvor_talk_website_id'));
    $config->set('hyvortalk.hyvor_talk_load_mode', $form_state->getValue('hyvor_talk_load_mode'));
    $config->save();
    \Drupal::service('cache.render')->invalidateAll();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!is_numeric($form_state->getValue('hyvor_talk_website_id'))){
      $form_state->setErrorByName('hyvor_talk_website_id', $this->t('The Hyvor Talk website ID should be a positive integer!'));
    }
  }

  /**
   * {@inheritdoc}
   */ 
  protected function getEditableConfigNames() {
    return [
      'hyvortalk.settings',
    ];
  }
 
}
