<?php

namespace Drupal\hyvortalk\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Session\AccountInterface;

/**
 * @Block(
 *   id = "hyvor_talk_block",
 *   admin_label = @Translation("Hyvor Talk comments"),
 *   context = {
 *     "node" = @ContextDefinition("entity:node")
 *   }
 * )
 */

class HyvorBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {

    $config = \Drupal::config('hyvortalk.settings');
    $node = $this->getContextValue('node');
    $website_id = $config->get('hyvortalk.hyvor_talk_website_id');

    if ( empty($website_id) )
      return [
        '#markup' => 'Hyvor Talk website ID is not defined in module configuration page!'
      ];
    else
      return [
        '#theme' => 'hyvor_template',
        '#nid' => $node->id(),
        '#lang' => \Drupal::languageManager()->getCurrentLanguage()->getId(),
        '#hyvor_talk_website_id' => $website_id,
        '#hyvor_talk_load_mode' => $config->get('hyvortalk.hyvor_talk_load_mode')
      ];
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'access hyvor talk comments');
  }

}
